@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from PIL import Image, ImageChops
-
 from pilgram import css
 from pilgram import util
 
@@ -33,8 +31,9 @@ def lark(im):
     cs1 = util.fill(cb.size, [34, 37, 63])
     cm1 = css.blending.color_dodge(cb, cs1)
 
-    cs2 = util.fill(cb.size, [242, 242, 242])
-    cm2 = ImageChops.darker(cm1, cs2)
-    cr = Image.blend(cm1, cm2, .8)
+    cs2 = util.fill(cb.size, [242, 242, 242, .8])
+    cr = css.blending.darken(cm1, cs2)
+
+    cr = css.contrast(cr, .9)
 
     return cr
