@@ -33,13 +33,11 @@ def mayfair(im):
     size = cb.size
     pos = (.4, .4)
 
-    cs1 = util.fill(size, [255, 255, 255])
+    cs1 = util.fill(size, [255, 255, 255, .8])
     cm1 = css.blending.overlay(cb, cs1)
-    cm1 = Image.blend(cb, cm1, .8)
 
-    cs2 = util.fill(size, [255, 200, 200])
+    cs2 = util.fill(size, [255, 200, 200, .6])
     cm2 = css.blending.overlay(cb, cs2)
-    cm2 = Image.blend(cb, cm2, .6)
 
     cs3 = util.fill(size, [17, 17, 17])
     cm3 = css.blending.overlay(cb, cs3)
@@ -49,7 +47,7 @@ def mayfair(im):
 
     mask2 = util.radial_gradient_mask(size, length=.3, scale=.6, center=pos)
     cs = Image.composite(cs, cm3, mask2)
-    cr = Image.blend(cb, cs, .4)
+    cr = Image.blend(cb, cs, .4)  # opacity
 
     cr = css.contrast(cr, 1.1)
     cr = css.saturate(cr, 1.1)
