@@ -32,7 +32,7 @@ def reyes(im):
 
     cs = util.fill(cb.size, [239, 205, 173])
     cs = css.blending.soft_light(cb, cs)
-    cr = Image.blend(cb, cs, .5)
+    cr = Image.blend(cb, cs, .5)  # opacity
 
     cr = css.sepia(cr, .22)
     cr = css.brightness(cr, 1.1)
