@@ -32,7 +32,7 @@ def valencia(im):
 
     cs = util.fill(cb.size, [58, 3, 57])
     cs = css.blending.exclusion(cb, cs)
-    cr = Image.blend(cb, cs, .5)
+    cr = Image.blend(cb, cs, .5)  # opacity
 
     cr = css.contrast(cr, 1.08)
     cr = css.brightness(cr, 1.08)
